;; Generated package description from pulsar.el  -*- no-byte-compile: t -*-
(define-package "pulsar" "0.4.0" "Pulse highlight on demand or after select functions" '((emacs "27.1")) :commit "1b91e34af63240fcfc02e267d740a78590f1f2de" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Pulsar Development" . "~protesilaos/pulsar@lists.sr.ht") :keywords '("convenience" "pulse" "highlight") :url "https://git.sr.ht/~protesilaos/pulsar")
